@@ -1,10 +1,10 @@
 
-# EASY-INSTALL-ENTRY-SCRIPT: 'wxPython==4.0.7.post2','console_scripts','img2py'
+# EASY-INSTALL-ENTRY-SCRIPT: 'wxPython==4.2.3','console_scripts','img2py'
 import re
 import sys
 
 # for compatibility with easy_install; see #2198
-__requires__ = 'wxPython==4.0.7.post2'
+__requires__ = 'wxPython==4.2.3'
 
 try:
     from importlib.metadata import distribution
@@ -30,4 +30,4 @@ globals().setdefault('load_entry_point', importlib_load_entry_point)
 
 if __name__ == '__main__':
     sys.argv[0] = re.sub(r'(-script\.pyw?|\.exe)?$', '', sys.argv[0])
-    sys.exit(load_entry_point('wxPython==4.0.7.post2', 'console_scripts', 'img2py')())
+    sys.exit(load_entry_point('wxPython==4.2.3', 'console_scripts', 'img2py')())
